# Star Ray XML

[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

An extension to the [star_ray](https://github.com/dicelab-rhul/star-ray) platform that uses XML as a description language for the state of an environment. Agents may use [xpath](https://www.w3schools.com/xml/xpath_intro.asp) expressions to query (read/write) to the state. 



## Quick Start

Install with pip 
```pip install star-ray-xml```


